Colour - Checker Detection
==========================

.. start-badges

|actions| |coveralls| |codacy| |version|

.. |actions| image:: https://github.com/colour-science/colour-checker-detection/workflows/Continuous%20Integration/badge.svg
    :target: https://github.com/colour-science/colour-checker-detection/actions
    :alt: Develop Build Status
.. |coveralls| image:: http://img.shields.io/coveralls/colour-science/colour-checker-detection/develop.svg?style=flat-square
    :target: https://coveralls.io/r/colour-science/colour-checker-detection
    :alt: Coverage Status
.. |codacy| image:: https://img.shields.io/codacy/grade/984900e3a85e40239a0f8f633dd1ebcb/develop.svg?style=flat-square
    :target: https://www.codacy.com/app/colour-science/colour-checker-detection
    :alt: Code Grade
.. |version| image:: https://img.shields.io/pypi/v/colour-checker-detection.svg?style=flat-square
    :target: https://pypi.org/project/colour-checker-detection
    :alt: Package Version

.. end-badges


A `Python <https://www.python.org/>`__ package implementing various colour
checker detection algorithms and related utilities.

It is open source and freely available under the
`New BSD License <https://opensource.org/licenses/BSD-3-Clause>`__ terms.

..  image:: https://raw.githubusercontent.com/colour-science/colour-checker-detection/master/docs/_static/ColourCheckerDetection_001.png

.. contents:: **Table of Contents**
    :backlinks: none
    :depth: 3

.. sectnum::

Features
--------

The following colour checker detection algorithms are implemented:

-   Segmentation

Installation
------------

Because of their size, the resources dependencies needed to run the various
examples and unit tests are not provided within the Pypi package. They are
separately available as
`Git Submodules <https://git-scm.com/book/en/v2/Git-Tools-Submodules>`__
when cloning the
`repository <https://github.com/colour-science/colour-checker-detection>`__.

Primary Dependencies
^^^^^^^^^^^^^^^^^^^^

**Colour - Checker Detection** requires various dependencies in order to run:

-  `Python >=3.5 <https://www.python.org/download/releases/>`__
-  `Colour Science <https://www.colour-science.org>`__
-  `opencv-python >=4 <https://pypi.org/project/opencv-python/>`__

Pypi
^^^^

Once the dependencies satisfied, **Colour - Checker Detection** can be installed from
the `Python Package Index <http://pypi.python.org/pypi/colour-checker-detection>`__ by
issuing this command in a shell::

	pip install colour-checker-detection

The overall development dependencies are installed as follows::

    pip install 'colour-checker-detection[development]'

Usage
-----

API
^^^

The main reference for `Colour - Checker Detection <https://github.com/colour-science/colour-checker-detection>`__
is the `Colour - Checker Detection Manual <https://colour-checker-detection.readthedocs.io/en/latest/manual.html>`__.

Examples
^^^^^^^^

Various usage examples are available from the
`examples directory <https://github.com/colour-science/colour-checker-detection/tree/master/colour_checker_detection/examples>`__.

Contributing
------------

If you would like to contribute to `Colour - Checker Detection <https://github.com/colour-science/colour-checker-detection>`__,
please refer to the following `Contributing <https://www.colour-science.org/contributing/>`__
guide for `Colour <https://github.com/colour-science/colour>`__.

Bibliography
------------

The bibliography is available in the repository in
`BibTeX <https://github.com/colour-science/colour-checker-detection/blob/develop/BIBLIOGRAPHY.bib>`__
format.

Code of Conduct
---------------

The *Code of Conduct*, adapted from the `Contributor Covenant 1.4 <https://www.contributor-covenant.org/version/1/4/code-of-conduct.html>`__,
is available on the `Code of Conduct <https://www.colour-science.org/code-of-conduct/>`__ page.

About
-----

| **Colour - Checker Detection** by Colour Developers
| Copyright © 2018-2019 – Colour Developers – `colour-science@googlegroups.com <colour-science@googlegroups.com>`__
| This software is released under terms of New BSD License: https://opensource.org/licenses/BSD-3-Clause
| `https://github.com/colour-science/colour-checker-detection <https://github.com/colour-science/colour-checker-detection>`__
